@@ -1,11 +1,9 @@
 use rustc::hir::def::Res;
 use rustc::hir::*;
 use rustc::lint::LateContext;
-use rustc::middle::expr_use_visitor::*;
-use rustc::middle::mem_categorization::cmt_;
-use rustc::middle::mem_categorization::Categorization;
 use rustc::ty;
 use rustc_data_structures::fx::FxHashSet;
+use rustc_typeck::expr_use_visitor::*;
 
 /// Returns a set of mutated local variable IDs, or `None` if mutations could not be determined.
 pub fn mutated_variables<'a, 'tcx>(expr: &'tcx Expr, cx: &'a LateContext<'a, 'tcx>) -> Option<FxHashSet<HirId>> {
@@ -14,16 +12,9 @@ pub fn mutated_variables<'a, 'tcx>(expr: &'tcx Expr, cx: &'a LateContext<'a, 'tc
         skip: false,
     };
     let def_id = def_id::DefId::local(expr.hir_id.owner);
-    let region_scope_tree = &cx.tcx.region_scope_tree(def_id);
-    ExprUseVisitor::new(
-        &mut delegate,
-        cx.tcx,
-        def_id,
-        cx.param_env,
-        region_scope_tree,
-        cx.tables,
-    )
-    .walk_expr(expr);
+    cx.tcx.infer_ctxt().enter(|infcx| {
+        ExprUseVisitor::new(&mut delegate, &infcx, def_id, cx.param_env, cx.tables).walk_expr(expr);
+    });
 
     if delegate.skip {
         return None;
@@ -46,33 +37,32 @@ struct MutVarsDelegate {
 
 impl<'tcx> MutVarsDelegate {
     #[allow(clippy::similar_names)]
-    fn update(&mut self, cat: &'tcx Categorization<'_>) {
-        match *cat {
-            Categorization::Local(id) => {
+    fn update(&mut self, cat: &Place<'tcx>) {
+        match cat.base {
+            PlaceBase::Local(id) => {
                 self.used_mutably.insert(id);
             },
-            Categorization::Upvar(_) => {
+            PlaceBase::Upvar(_) => {
                 //FIXME: This causes false negatives. We can't get the `NodeId` from
                 //`Categorization::Upvar(_)`. So we search for any `Upvar`s in the
                 //`while`-body, not just the ones in the condition.
                 self.skip = true
             },
-            Categorization::Deref(ref cmt, _) | Categorization::Interior(ref cmt, _) => self.update(&cmt.cat),
             _ => {},
         }
     }
 }
 
 impl<'tcx> Delegate<'tcx> for MutVarsDelegate {
-    fn consume(&mut self, _: &cmt_<'tcx>, _: ConsumeMode) {}
+    fn consume(&mut self, _: &Place<'tcx>, _: ConsumeMode) {}
 
-    fn borrow(&mut self, cmt: &cmt_<'tcx>, bk: ty::BorrowKind) {
+    fn borrow(&mut self, cmt: &Place<'tcx>, bk: ty::BorrowKind) {
         if let ty::BorrowKind::MutBorrow = bk {
-            self.update(&cmt.cat)
+            self.update(&cmt)
         }
     }
 
-    fn mutate(&mut self, cmt: &cmt_<'tcx>) {
-        self.update(&cmt.cat)
+    fn mutate(&mut self, cmt: &Place<'tcx>) {
+        self.update(&cmt)
     }
 }
