@@ -1,13 +1,13 @@
-use std::borrow::Cow;
-
 use syntax::source_map::{BytePos, Pos, Span};
 
 use crate::comment::{is_last_comment_block, rewrite_comment, CodeCharKind, CommentCodeSlices};
 use crate::config::file_lines::FileLines;
-use crate::config::{EmitMode, FileName};
+use crate::config::FileName;
+use crate::config::Version;
+use crate::coverage::transform_missing_snippet;
 use crate::shape::{Indent, Shape};
 use crate::source_map::LineRangeUtils;
-use crate::utils::{count_newlines, last_line_width, mk_sp};
+use crate::utils::{count_lf_crlf, count_newlines, last_line_width, mk_sp};
 use crate::visitor::FmtVisitor;
 
 struct SnippetStatus {
@@ -157,7 +157,7 @@ impl<'a> FmtVisitor<'a> {
     fn write_snippet_inner<F>(
         &mut self,
         big_snippet: &str,
-        mut big_diff: usize,
+        big_diff: usize,
         old_snippet: &str,
         span: Span,
         process_last_snippet: F,
@@ -171,41 +171,28 @@ impl<'a> FmtVisitor<'a> {
         let file_name = &char_pos.file.name.clone().into();
         let mut status = SnippetStatus::new(char_pos.line);
 
-        let snippet = &*match self.config.emit_mode() {
-            EmitMode::Coverage => Cow::from(replace_chars(old_snippet)),
-            _ => Cow::from(old_snippet),
-        };
+        let snippet = &*transform_missing_snippet(self.config, old_snippet);
 
-        // if the snippet starts with a new line, then information about the lines needs to be
-        // adjusted since it is off by 1.
-        let snippet = if snippet.starts_with('\n') {
-            // this takes into account the blank_lines_* options
-            self.push_vertical_spaces(1);
-            // include the newline character into the big_diff
-            big_diff += 1;
-            status.cur_line += 1;
-            &snippet[1..]
-        } else {
-            snippet
-        };
-
-        let slice_within_file_lines_range = |file_lines: FileLines, cur_line, s| -> (usize, bool) {
-            let newline_count = count_newlines(s);
-            let within_file_lines_range = file_lines.contains_range(
-                file_name,
-                cur_line,
-                // if a newline character is at the end of the slice, then the number of newlines
-                // needs to be decreased by 1 so that the range checked against the file_lines is
-                // the visual range one would expect.
-                cur_line + newline_count - if s.ends_with('\n') { 1 } else { 0 },
-            );
-            (newline_count, within_file_lines_range)
-        };
+        let slice_within_file_lines_range =
+            |file_lines: FileLines, cur_line, s| -> (usize, usize, bool) {
+                let (lf_count, crlf_count) = count_lf_crlf(s);
+                let newline_count = lf_count + crlf_count;
+                let within_file_lines_range = file_lines.contains_range(
+                    file_name,
+                    cur_line,
+                    // if a newline character is at the end of the slice, then the number of
+                    // newlines needs to be decreased by 1 so that the range checked against
+                    // the file_lines is the visual range one would expect.
+                    cur_line + newline_count - if s.ends_with('\n') { 1 } else { 0 },
+                );
+                (lf_count, crlf_count, within_file_lines_range)
+            };
         for (kind, offset, subslice) in CommentCodeSlices::new(snippet) {
             debug!("{:?}: {:?}", kind, subslice);
 
-            let (newline_count, within_file_lines_range) =
+            let (lf_count, crlf_count, within_file_lines_range) =
                 slice_within_file_lines_range(self.config.file_lines(), status.cur_line, subslice);
+            let newline_count = lf_count + crlf_count;
             if CodeCharKind::Comment == kind && within_file_lines_range {
                 // 1: comment.
                 self.process_comment(
@@ -219,7 +206,7 @@ impl<'a> FmtVisitor<'a> {
                 // 2: blank lines.
                 self.push_vertical_spaces(newline_count);
                 status.cur_line += newline_count;
-                status.line_start = offset + newline_count;
+                status.line_start = offset + lf_count + crlf_count * 2;
             } else {
                 // 3: code which we failed to format or which is not within file-lines range.
                 self.process_missing_code(&mut status, snippet, subslice, offset, file_name);
@@ -227,7 +214,7 @@ impl<'a> FmtVisitor<'a> {
         }
 
         let last_snippet = &snippet[status.line_start..];
-        let (_, within_file_lines_range) =
+        let (_, _, within_file_lines_range) =
             slice_within_file_lines_range(self.config.file_lines(), status.cur_line, last_snippet);
         if within_file_lines_range {
             process_last_snippet(self, last_snippet, snippet);
@@ -252,6 +239,7 @@ impl<'a> FmtVisitor<'a> {
             .next();
 
         let fix_indent = last_char.map_or(true, |rev_c| ['{', '\n'].contains(&rev_c));
+        let mut on_same_line = false;
 
         let comment_indent = if fix_indent {
             if let Some('{') = last_char {
@@ -260,6 +248,13 @@ impl<'a> FmtVisitor<'a> {
             let indent_str = self.block_indent.to_string(self.config);
             self.push_str(&indent_str);
             self.block_indent
+        } else if self.config.version() == Version::Two && !snippet.starts_with('\n') {
+            // The comment appears on the same line as the previous formatted code.
+            // Assuming that comment is logically associated with that code, we want to keep it on
+            // the same level and avoid mixing it with possible other comment.
+            on_same_line = true;
+            self.push_str(" ");
+            self.block_indent
         } else {
             self.push_str(" ");
             Indent::from_width(self.config, last_line_width(&self.buffer))
@@ -270,9 +265,34 @@ impl<'a> FmtVisitor<'a> {
             self.config.max_width() - self.block_indent.width(),
         );
         let comment_shape = Shape::legacy(comment_width, comment_indent);
-        let comment_str = rewrite_comment(subslice, false, comment_shape, self.config)
-            .unwrap_or_else(|| String::from(subslice));
-        self.push_str(&comment_str);
+
+        if on_same_line {
+            match subslice.find("\n") {
+                None => {
+                    self.push_str(subslice);
+                }
+                Some(offset) if offset + 1 == subslice.len() => {
+                    self.push_str(&subslice[..offset]);
+                }
+                Some(offset) => {
+                    // keep first line as is: if it were too long and wrapped, it may get mixed
+                    // with the other lines.
+                    let first_line = &subslice[..offset];
+                    self.push_str(first_line);
+                    self.push_str(&comment_indent.to_string_with_newline(self.config));
+
+                    let other_lines = &subslice[offset + 1..];
+                    let comment_str =
+                        rewrite_comment(other_lines, false, comment_shape, self.config)
+                            .unwrap_or_else(|| String::from(other_lines));
+                    self.push_str(&comment_str);
+                }
+            }
+        } else {
+            let comment_str = rewrite_comment(subslice, false, comment_shape, self.config)
+                .unwrap_or_else(|| String::from(subslice));
+            self.push_str(&comment_str);
+        }
 
         status.last_wspace = None;
         status.line_start = offset + subslice.len();
@@ -343,10 +363,3 @@ impl<'a> FmtVisitor<'a> {
         }
     }
 }
-
-fn replace_chars(string: &str) -> String {
-    string
-        .chars()
-        .map(|ch| if ch.is_whitespace() { ch } else { 'X' })
-        .collect()
-}
