@@ -10,7 +10,6 @@ use std::cmp::{Ord, Ordering};
 
 use syntax::{ast, attr, source_map::Span, symbol::sym};
 
-use crate::attr::filter_inline_attrs;
 use crate::config::Config;
 use crate::imports::{merge_use_trees, UseTree};
 use crate::items::{is_mod_decl, rewrite_extern_crate, rewrite_mod};
@@ -24,7 +23,7 @@ use crate::visitor::FmtVisitor;
 
 /// Choose the ordering between the given two items.
 fn compare_items(a: &ast::Item, b: &ast::Item) -> Ordering {
-    match (&a.node, &b.node) {
+    match (&a.kind, &b.kind) {
         (&ast::ItemKind::Mod(..), &ast::ItemKind::Mod(..)) => {
             a.ident.as_str().cmp(&b.ident.as_str())
         }
@@ -69,7 +68,7 @@ fn rewrite_reorderable_item(
     item: &ast::Item,
     shape: Shape,
 ) -> Option<String> {
-    match item.node {
+    match item.kind {
         ast::ItemKind::ExternCrate(..) => rewrite_extern_crate(context, item, shape),
         ast::ItemKind::Mod(..) => rewrite_mod(context, item, shape),
         _ => None,
@@ -84,7 +83,7 @@ fn rewrite_reorderable_items(
     shape: Shape,
     span: Span,
 ) -> Option<String> {
-    match reorderable_items[0].node {
+    match reorderable_items[0].kind {
         // FIXME: Remove duplicated code.
         ast::ItemKind::Use(..) => {
             let mut normalized_items: Vec<_> = reorderable_items
@@ -149,10 +148,7 @@ fn rewrite_reorderable_items(
 }
 
 fn contains_macro_use_attr(item: &ast::Item) -> bool {
-    attr::contains_name(
-        &filter_inline_attrs(&item.attrs, item.span()),
-        sym::macro_use,
-    )
+    attr::contains_name(&item.attrs, sym::macro_use)
 }
 
 /// A simplified version of `ast::ItemKind`.
@@ -168,7 +164,7 @@ enum ReorderableItemKind {
 
 impl ReorderableItemKind {
     fn from(item: &ast::Item) -> Self {
-        match item.node {
+        match item.kind {
             _ if contains_macro_use_attr(item) | contains_skip(&item.attrs) => {
                 ReorderableItemKind::Other
             }
